-- Detlef von Reusner
-- Saab 340B Carenado - Annunciator Panel
-- April 29 2021

local ImgBackground = img_add_fullscreen("bg-empty.png")

local gTextStyle = "font:FreeSansBold.ttf; size:21; halign:center"
local gTextColor = string.format(";color:#%02X%02X%02X", 90, 90, 90)
local gLamp = {}
local gCount = 0
local gCTOT = 0 -- 0 1 2 off on apr
local gAutoCoarsen = 0 -- 1 == is on

L_BLUE = "blue2.png"
L_GRAY = "gray2.png"
L_GREEN = "green2.png"
L_ALMOST_BLUE = "almost-blue2.png"
L_OFF = "off.png"
OPACITY = .6

local gDim = {}
gDim.x_start = 63
gDim.y_start = 25
gDim.frame_width = 150
gDim.frame_height = 74
gDim.x_step = 147
gDim.y_step = 72

for k=0, 11 do
  x = k % 2 * gDim.x_step + gDim.x_start
  y = math.floor(k/2) * gDim.y_step + gDim.y_start
  img_add("frame.png", x, y, gDim.frame_width, gDim.frame_height)
end

function AddLamp(color, line1, line2)
  gCount = gCount + 1
  gLamp[gCount] = {}
  local w = gLamp[gCount]
  
  if  resource_info(color) == nil then
    print("Error: Cannot open " .. color)
    return
  end
  
  local column = math.fmod((gCount-1),2)
  local line = math.floor((gCount-1)/2)
  local x = gDim.x_start + 12 + (column * gDim.x_step)
  local y = gDim.y_start + 10 + (line * gDim.y_step)
  w.width = 126
  w.height = 52

  w.id_on = img_add(color, x, y, w.width, w.height, "visible:true")
  w.id_off = img_add(L_OFF, x, y, w.width, w.height, "visible:true")
  opacity(w.id_off, OPACITY)

  if line2 == nil then
    txt_add(line1, gTextStyle..gTextColor, x+1, y+15, w.width, w.height)
  else
    txt_add(line1, gTextStyle..gTextColor, x+1, y+5, w.width, w.height)
    txt_add(line2, gTextStyle..gTextColor, x+1, y+27, w.width, w.height)
  end
  w.is_on = false
end

-- numbered 1 .. 12, left right top bottom
AddLamp(L_GREEN, "L BETA")
AddLamp(L_GREEN, "R BETA")
AddLamp(L_BLUE, "L PROP", "DE-ICE")
AddLamp(L_BLUE, "R PROP", "DE-ICE")
AddLamp(L_BLUE, "L ENG", "ANTI ICE")
AddLamp(L_BLUE, "R ENG", "ANTI ICE")
AddLamp(L_GREEN, "L APR")
AddLamp(L_GREEN, "R APR")
AddLamp(L_ALMOST_BLUE, "AUTOCOARS", "HIGH")
AddLamp(L_ALMOST_BLUE, "AUTOCOARS", "LOW")
AddLamp(L_GRAY, "L IGN")
AddLamp(L_GRAY, "R IGN")

function SwitchLampOn(index, to_on, test)
  local w = gLamp[index]
  if w.is_on == nil then return end
  if test == nil or test == false then
    w.is_on = to_on
  end
  if to_on then
    opacity(w.id_off, 0)
  else
    opacity(w.id_off, OPACITY)
  end
end

-----------------------------------------------------

function cbIgnition(v)
  SwitchLampOn(11, v[1] == 1)
  SwitchLampOn(12, v[2] == 1)
end
xpl_dataref_subscribe("sim/cockpit2/engine/indicators/igniter_sparking", "INT[8]", cbIgnition)

function cbBeta(v)
  SwitchLampOn(1, v[1] == 1)
  SwitchLampOn(2, v[2] == 1)
end
xpl_dataref_subscribe("sim/cockpit2/annunciators/beta", "INT[8]", cbBeta)

function cbAntiIce(v)
  SwitchLampOn(5, v[1] == 1)
  SwitchLampOn(6, v[2] == 1)
end
xpl_dataref_subscribe("sim/cockpit/switches/anti_ice_inlet_heat_per_engine", "INT[8]", cbAntiIce)

function cbDeIceProp(v)
  SwitchLampOn(3, v[1] ~= 0)
  SwitchLampOn(4, v[2] ~= 0)
end
xpl_dataref_subscribe("sim/cockpit/switches/anti_ice_prop_heat_per_engine", "INT[8]", cbDeIceProp)


function cbFeather(arm)
  -- arm[] == 1 when  thrustlevers above yellow line
  if gAutoCoarsen == 1 then
    if arm[1] == 0 or arm[2] == 0 then
      SwitchLampOn(7, false) -- L APR
      SwitchLampOn(8, false) -- R APR
      SwitchLampOn(9, false) -- AUTOCOARS HIGH
      SwitchLampOn(10, true) -- AUTOCOARS LOW
    else
      if gCTOT == 1 then -- ON
        SwitchLampOn(7, false)
        SwitchLampOn(8, false)
        SwitchLampOn(9, true)
        SwitchLampOn(10, false)
      elseif gCTOT == 2 then -- APR
        SwitchLampOn(7, arm[1] == 1)
        SwitchLampOn(8, arm[2] == 1)
        SwitchLampOn(9, true)
        SwitchLampOn(10, false)
      else
        SwitchLampOn(7, false)
        SwitchLampOn(8, false)
        SwitchLampOn(9, false)
        SwitchLampOn(10, true) -- AUTOCOARS LOW
      end
    end
  else
    SwitchLampOn(7, false)
    SwitchLampOn(8, false)
    SwitchLampOn(9, false)
    SwitchLampOn(10, false)
  end
end
xpl_dataref_subscribe("sim/cockpit/warnings/annunciators/auto_feather_arm", "INT[8]", cbFeather)

function cbAutoCoarse(v)
  gAutoCoarsen = v
  request_callback(cbFeather)
end
xpl_dataref_subscribe("sim/cockpit/switches/auto_feather_mode", "INT", cbAutoCoarse)

function cbCTOT(v)
  gCTOT = v
  request_callback(cbFeather)
end
xpl_dataref_subscribe("thranda/engine/CTOT", "INT", cbCTOT)


-- sim/cockpit/warnings/annunciators/auto_feather_arm 1 == on (0 == autocourse low light is off)
-- sim/cockpit/warnings/annunciators/auto_feather_arm gehen auf 1, sobald Schubgrenze überschritten, Licht geht von LOW auf HIGH
-- Schubgrenze ist yellow line

-- AUTOCOARSE ganz aus, wenn autocoarse switch off
-- beim start mit CTOT in APR gehen L APR und R APR an.
-- beim Start mit CTOT in ON bleiben APR aus, aber L COARSE HIGH geht analytics.init()


